<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Overwrite parent theme background defaults and registers support for WordPress features.
add_action( 'after_setup_theme', 'lalita_background_setup' );
function lalita_background_setup() {
	add_theme_support( "custom-background",
		array(
			'default-color' 		 => 'f5f5ee',
			'default-image'          => '',
			'default-repeat'         => 'repeat',
			'default-position-x'     => 'left',
			'default-position-y'     => 'top',
			'default-size'           => 'auto',
			'default-attachment'     => '',
			'wp-head-callback'       => '_custom_background_cb',
			'admin-head-callback'    => '',
			'admin-preview-callback' => ''
		)
	);
}

// Overwrite theme URL
function lalita_theme_uri_link() {
	return 'https://wpkoi.com/phala-wpkoi-wordpress-theme/';
}

// Overwrite parent theme's blog header function
add_action( 'lalita_after_header', 'lalita_blog_header_image', 11 );
function lalita_blog_header_image() {

	if ( ( is_front_page() && is_home() ) || ( is_home() ) ) { 
		$blog_header_image 			=  lalita_get_setting( 'blog_header_image' ); 
		$blog_header_title 			=  lalita_get_setting( 'blog_header_title' ); 
		$blog_header_text 			=  lalita_get_setting( 'blog_header_text' ); 
		$blog_header_button_text 	=  lalita_get_setting( 'blog_header_button_text' ); 
		$blog_header_button_url 	=  lalita_get_setting( 'blog_header_button_url' ); 
		if ( $blog_header_image != '' ) { ?>
		<div class="page-header-image grid-parent page-header-blog" style="background-image: url('<?php echo esc_url($blog_header_image); ?>') !important;">
        	<div class="page-header-noiseoverlay"></div>
        	<div class="page-header-blog-inner">
                <div class="page-header-blog-content-h grid-container">
                    <div class="page-header-blog-content">
                    <?php if ( $blog_header_title != '' ) { ?>
                        <div class="page-header-blog-text">
                            <?php if ( $blog_header_title != '' ) { ?>
                            <h2><?php echo wp_kses_post( $blog_header_title ); ?></h2>
                            <div class="clearfix"></div>
                            <?php } ?>
                        </div>
                    <?php } ?>
                    </div>
                </div>
                <div class="page-header-blog-content page-header-blog-content-b">
                	<?php if ( $blog_header_text != '' ) { ?>
                	<div class="page-header-blog-text">
						<?php if ( $blog_header_title != '' ) { ?>
                        <p><?php echo wp_kses_post( $blog_header_text ); ?></p>
                        <div class="clearfix"></div>
                        <?php } ?>
                    </div>
                    <?php } ?>
                    <div class="page-header-blog-button">
                        <?php if ( $blog_header_button_text != '' ) { ?>
                        <a class="read-more button" href="<?php echo esc_url( $blog_header_button_url ); ?>"><?php echo esc_html( $blog_header_button_text ); ?></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
		</div>
		<?php
		}
	}
}

// Extra cutomizer functions
if ( ! function_exists( 'phala_customize_register' ) ) {
	add_action( 'customize_register', 'phala_customize_register' );
	function phala_customize_register( $wp_customize ) {
				
		// Add Phala customizer section
		$wp_customize->add_section(
			'phala_layout_effects',
			array(
				'title' => __( 'Phala Effects', 'phala' ),
				'priority' => 24,
			)
		);
		
		// Add navigation extra button text
		$wp_customize->add_setting(
			'phala_settings[nav_btn_text]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			'phala_settings[nav_btn_text]',
			array(
				'type' => 'text',
				'label' => __( 'Navigation button text', 'phala' ),
				'section' => 'phala_layout_effects',
				'settings' => 'phala_settings[nav_btn_text]',
				'priority' => 15
			)
		);
		
		// Add navigation extra button url
		$wp_customize->add_setting(
			'phala_settings[nav_btn_url]',
			array(
				'default' => '',
				'type' => 'option',
				'sanitize_callback' => 'esc_url'
			)
		);

		$wp_customize->add_control(
			'phala_settings[nav_btn_url]',
			array(
				'type' => 'text',
				'label' => __( 'Navigation button URL', 'phala' ),
				'section' => 'phala_layout_effects',
				'settings' => 'phala_settings[nav_btn_url]',
				'priority' => 15
			)
		);
		
		// Nav button hover effect
		$wp_customize->add_setting(
			'phala_settings[nav_btn_hover_effect]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'phala_settings[nav_btn_hover_effect]',
			array(
				'type' => 'select',
				'label' => __( 'Nav button hover effect', 'phala' ),
				'choices' => array(
					'enable' => __( 'Enable', 'phala' ),
					'disable' => __( 'Disable', 'phala' )
				),
				'settings' => 'phala_settings[nav_btn_hover_effect]',
				'section' => 'phala_layout_effects',
				'priority' => 20
			)
		);
		
		// Unique scrollbar
		$wp_customize->add_setting(
			'phala_settings[unique_scrollbar]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'phala_settings[unique_scrollbar]',
			array(
				'type' => 'select',
				'label' => __( 'Unique scrollbar', 'phala' ),
				'choices' => array(
					'enable' => __( 'Enable', 'phala' ),
					'disable' => __( 'Disable', 'phala' )
				),
				'settings' => 'phala_settings[unique_scrollbar]',
				'section' => 'phala_layout_effects',
				'priority' => 30
			)
		);
		
		// Blog image border
		$wp_customize->add_setting(
			'phala_settings[blog_img]',
			array(
				'default' => 'enable',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_choices'
			)
		);

		$wp_customize->add_control(
			'phala_settings[blog_img]',
			array(
				'type' => 'select',
				'label' => __( 'Blog image border', 'phala' ),
				'choices' => array(
					'enable' => __( 'Enable', 'phala' ),
					'disable' => __( 'Disable', 'phala' )
				),
				'settings' => 'phala_settings[blog_img]',
				'section' => 'phala_layout_effects',
				'priority' => 40
			)
		);
		
		// Phala effect colors
		$wp_customize->add_setting(
			'phala_settings[phala_color_1]', array(
				'default' => '#f5f5ee',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'phala_settings[phala_color_1]',
				array(
					'label' => __( 'Effect color', 'phala' ),
					'section' => 'phala_layout_effects',
					'settings' => 'phala_settings[phala_color_1]',
					'priority' => 45
				)
			)
		);
		
		$wp_customize->add_setting(
			'phala_settings[phala_color_2]', array(
				'default' => '#222222',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'phala_settings[phala_color_2]',
				array(
					'label' => __( 'Effect color 2', 'phala' ),
					'section' => 'phala_layout_effects',
					'settings' => 'phala_settings[phala_color_2]',
					'priority' => 46
				)
			)
		);
		
		$wp_customize->add_setting(
			'phala_settings[phala_color_3]', array(
				'default' => '#fec42c',
				'type' => 'option',
				'sanitize_callback' => 'phala_sanitize_hex_color',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'phala_settings[phala_color_3]',
				array(
					'label' => __( 'Effect color 3', 'phala' ),
					'section' => 'phala_layout_effects',
					'settings' => 'phala_settings[phala_color_3]',
					'priority' => 47
				)
			)
		);
	}
}

//Sanitize choices.
if ( ! function_exists( 'phala_sanitize_choices' ) ) {
	function phala_sanitize_choices( $input, $setting ) {
		// Ensure input is a slug
		$input = sanitize_key( $input );

		// Get list of choices from the control
		// associated with the setting
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it;
		// otherwise, return the default
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}
}

// Sanitize colors. Allow blank value.
if ( ! function_exists( 'phala_sanitize_hex_color' ) ) {
	function phala_sanitize_hex_color( $color ) {
	    if ( '' === $color ) {
	        return '';
		}

	    // 3 or 6 hex digits, or the empty string.
	    if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
	        return $color;
		}

	    return '';
	}
}

// Phala effects colors css
if ( ! function_exists( 'phala_effect_colors_css' ) ) {
	function phala_effect_colors_css() {
		// Get Customizer settings
		$phala_settings = get_option( 'phala_settings' );
		
		$phala_color_1  	 = '#f5f5ee';
		$phala_color_2  	 = '#222222';
		$phala_color_3  	 = '#fec42c';
		if ( isset( $phala_settings['phala_color_1'] ) ) {
			$phala_color_1 = $phala_settings['phala_color_1'];
		}
		if ( isset( $phala_settings['phala_color_2'] ) ) {
			$phala_color_2 = $phala_settings['phala_color_2'];
		}
		if ( isset( $phala_settings['phala_color_3'] ) ) {
			$phala_color_3 = $phala_settings['phala_color_3'];
		}
		
		$lalita_settings = wp_parse_args(
			get_option( 'lalita_settings', array() ),
			lalita_get_color_defaults()
		);
		
		$phala_extracolors = '.phala-unique-scrollbar::-webkit-scrollbar-track {background: ' . esc_attr( $phala_color_1 ) . ';}.phala-unique-scrollbar::-webkit-scrollbar-thumb {background: ' . esc_attr( $phala_color_2 ) . ';border-color: ' . esc_attr( $phala_color_1 ) . ';}.phala-unique-scrollbar::-webkit-scrollbar-thumb:hover {background: ' . esc_attr( $phala_color_3 ) . ';}.phala-blog-img.blog .post-image img {border-color: ' . esc_attr( $phala_color_2 ) . ';}header .main-navigation .main-nav ul li a.wpkoi-nav-btn {background-color: ' . esc_attr( $phala_color_1 ) . '; color: ' . esc_attr( $phala_color_2 ) . ';border-color: ' . esc_attr( $phala_color_2 ) . ';} header .main-navigation .main-nav ul li a.wpkoi-nav-btn:hover {background-color: ' . esc_attr( $phala_color_2 ) . '; color: ' . esc_attr( $phala_color_1 ) . ';border-color: ' . esc_attr( $phala_color_2 ) . ';}';
		
		return $phala_extracolors;
	}
}

// The dynamic styles of the parent theme added inline to the parent stylesheet.
// For the customizer functions it is better to enqueue after the child theme stylesheet.
if ( ! function_exists( 'phala_remove_parent_dynamic_css' ) ) {
	add_action( 'init', 'phala_remove_parent_dynamic_css' );
	function phala_remove_parent_dynamic_css() {
		remove_action( 'wp_enqueue_scripts', 'lalita_enqueue_dynamic_css', 50 );
	}
}

// Enqueue this CSS after the child stylesheet, not after the parent stylesheet.
if ( ! function_exists( 'phala_enqueue_parent_dynamic_css' ) ) {
	add_action( 'wp_enqueue_scripts', 'phala_enqueue_parent_dynamic_css', 50 );
	function phala_enqueue_parent_dynamic_css() {
		$css = lalita_base_css() . lalita_font_css() . lalita_advanced_css() . lalita_spacing_css() . lalita_no_cache_dynamic_css() .phala_effect_colors_css();

		// escaped secure before in parent theme
		wp_add_inline_style( 'lalita-child', $css );
	}
}

//Adds custom classes to the array of body classes.
if ( ! function_exists( 'phala_body_classes' ) ) {
	add_filter( 'body_class', 'phala_body_classes' );
	function phala_body_classes( $classes ) {
		// Get Customizer settings
		$phala_settings = get_option( 'phala_settings' );
		
		$blog_img  	  = 'enable';
		$unique_scrollbar     = 'enable';
		
		if ( isset( $phala_settings['blog_img'] ) ) {
			$blog_img = $phala_settings['blog_img'];
		}
		
		if ( isset( $phala_settings['unique_scrollbar'] ) ) {
			$unique_scrollbar = $phala_settings['unique_scrollbar'];
		}
		
		// Blog image border
		if ( $blog_img != 'disable' ) {
			$classes[] = 'phala-blog-img';
		}
		
		// Unique scrollbar
		if ( $unique_scrollbar != 'disable' ) {
			$classes[] = 'phala-unique-scrollbar';
		}
		
		return $classes;
	}
}

// Add buton to main menu
if ( ! function_exists( 'phala_navigation_button' ) ) {
	add_filter( 'wp_nav_menu_items', 'phala_navigation_button', 11, 2 );
	/**
	 * Add the extra button to the navigation.
	 *
	 */
	function phala_navigation_button( $nav, $args ) {
		// Get Customizer settings
		$phala_settings = get_option( 'phala_settings' );
		
		// If our primary menu is set, add the extra button.
		if ( ( isset( $phala_settings['nav_btn_url'] ) ) && ( isset( $phala_settings['nav_btn_text'] ) ) && ( isset( $args->theme_location ) ) ) {
			if ( ( $args->theme_location == 'primary' ) && ( $phala_settings['nav_btn_url'] != '' ) ) {
				return $nav . '<li class="wpkoi-nav-btn-h"><div class="nav-btn-border"><a class="wpkoi-nav-btn button" href="' . esc_url( $phala_settings['nav_btn_url'] ) . '"><span class="link-text">' . esc_html( $phala_settings['nav_btn_text'] ) . '</span><span class="hover-wpkoi"></span></a></div></li>';
			}
		}
		
	    return $nav;
	}
}

// Nav button hover effect script
if ( ! function_exists( 'phala_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'phala_scripts' );
	/**
	 * Enqueue scripts and styles
	 */
	function phala_scripts() {

		$dir_uri = get_stylesheet_directory_uri();
		// Get Customizer settings
		$phala_settings = get_option( 'phala_settings' );
		$nav_btn_hover_effect  = 'enable';
		if ( isset( $phala_settings['nav_btn_hover_effect'] ) ) {
			$nav_btn_hover_effect = $phala_settings['nav_btn_hover_effect'];
		}
		
		if ( $nav_btn_hover_effect != 'disable' ) {
			wp_enqueue_script( 'phala-navbtn', esc_url( $dir_uri ) . "/js/navbtn.min.js", array( 'jquery'), LALITA_VERSION, true );
		}
	}
}